=== modified file 'storm/store.py'
--- storm/store.py	2008-10-17 05:49:15 +0000
+++ storm/store.py	2008-11-03 21:35:05 +0000
@@ -49,6 +49,10 @@
 PENDING_REMOVE = 2
 
 
+# The maximum number of objects the cache should have per default.
+DEFAULT_CACHE_SIZE = 100
+
+
 class Store(object):
     """The Storm Store.
 
@@ -63,15 +67,17 @@
 
     _result_set_factory = None
 
-    def __init__(self, database):
+    def __init__(self, database, cache_size=DEFAULT_CACHE_SIZE):
         """
         @param database: The L{storm.database.Database} instance to use.
+        @param cache_size: The maximum number of objects the internal cache
+            should keep alive.  Defaults to L{DEFAULT_CACHE_SIZE}.
         """
         self._connection = database.connect()
         self._alive = WeakValueDictionary()
         self._dirty = {}
         self._order = {} # (info, info) = count
-        self._cache = Cache(100)
+        self._cache = Cache(cache_size)
         self._implicit_flush_block_count = 0
         self._sequence = 0 # Advisory ordering.
         self._event = EventSystem(self)

=== modified file 'tests/store/base.py'
--- tests/store/base.py	2008-11-03 19:38:06 +0000
+++ tests/store/base.py	2008-11-03 21:35:05 +0000
@@ -35,10 +35,10 @@
 from storm.info import get_obj_info, ClassAlias
 from storm.exceptions import *
 from storm.store import *
-from storm.store import ResultSet
+from storm.store import ResultSet, DEFAULT_CACHE_SIZE
 
 from tests.info import Wrapper
-from tests.helper import run_this
+from tests.helper import run_this, TestHelper
 
 
 class Foo(object):
@@ -130,6 +130,25 @@
     title = Property(variable_class=DecorateVariable)
 
 
+class DummyDatabase(object):
+
+    def connect(self):
+        return None
+
+
+class StoreCacheTest(TestHelper):
+
+    def test_wb_variable_cache_size(self):
+        # Ensure that the tested size is different from the default one.
+        variable_size = DEFAULT_CACHE_SIZE + 10
+        store = Store(DummyDatabase(), cache_size=variable_size)
+        self.assertEquals(store._cache._size, variable_size)
+
+    def test_wb_default_cache_size(self):
+        store = Store(DummyDatabase())
+        self.assertEquals(store._cache._size, DEFAULT_CACHE_SIZE)
+
+
 class StoreTest(object):
 
     def setUp(self):

